==> pochy-0.1.4a-src.tar.gz: pochy-0.1.4a-src/AttachedFileView.h <==
#if !defined(AFX_MOOLISTVIEW2_H__5DA2FA00_81C5_11D5_B88F_00402676496C__INCLUDED_)
#define AFX_MOOLISTVIEW2_H__5DA2FA00_81C5_11D5_B88F_00402676496C__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// AttachedFileView.h :
//
#include <afxcview.h>

/////////////////////////////////////////////////////////////////////////////
// CAttachedFileView r[

class CAttachedFileView : public CListView
{
protected:
	CAttachedFileView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CAttachedFileView)

// Agr[g
public:
	int m_index;
//  DWORD m_image_multipart; // }`p[g̃ACRCfbNX
//  DWORD m_image_up; // ̊Kw̃ACRCfbNX

//protected:
	CImageList m_image;
// Iy[V
public:
	void AddPgpKey();
	void AddFile(LPSTR file_path);
	void ReArrange();
	void ExecuteFile();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CAttachedFileView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CAttachedFileView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CAttachedFileView)
	afx_msg void OnRclick(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnDblclk(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnRemoveFile();
	afx_msg void OnItemchanged(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOOLISTVIEW2_H__5DA2FA00_81C5_11D5_B88F_00402676496C__INCLUDED_)

==> pochy-0.1.9-src.tar.gz: pochy-0.1.9-src/AttachedFileView.h <==
#if !defined(AFX_MOOLISTVIEW2_H__5DA2FA00_81C5_11D5_B88F_00402676496C__INCLUDED_)
#define AFX_MOOLISTVIEW2_H__5DA2FA00_81C5_11D5_B88F_00402676496C__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// AttachedFileView.h :
//
#include <afxcview.h>
// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
#include "BitmapListView.h"
// end

/////////////////////////////////////////////////////////////////////////////
// CAttachedFileView r[

// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
// start
//class CAttachedFileView : public CListView
class CAttachedFileView : public CBitmapListView
// end
{
protected:
	CAttachedFileView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CAttachedFileView)

// Agr[g
public:
	int m_index;
//  DWORD m_image_multipart; // }`p[g̃ACRCfbNX
//  DWORD m_image_up; // ̊Kw̃ACRCfbNX

//protected:
	CImageList m_image;
// Iy[V
public:
	void AddPgpKey();
	void AddFile(LPSTR file_path);
	void ReArrange();
	void ExecuteFile();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CAttachedFileView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CAttachedFileView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CAttachedFileView)
	afx_msg void OnRclick(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnDblclk(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnRemoveFile();
	afx_msg void OnItemchanged(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg void OnChar(UINT nChar, UINT nRepCnt, UINT nFlags);
	afx_msg void OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MOOLISTVIEW2_H__5DA2FA00_81C5_11D5_B88F_00402676496C__INCLUDED_)
